@@ -6,7 +6,7 @@
  *   copyright            : (C) 2001 The phpBB Group
  *   email                : support@phpbb.com
  *
- *   $Id: admin_styles.php,v 1.27.2.13 2004/07/15 17:57:50 acydburn Exp $
+ *   $Id: admin_styles.php,v 1.27.2.15 2005/10/04 21:45:02 grahamje Exp $
  *
  *
  ***************************************************************************/
@@ -75,7 +75,7 @@ switch( $mode )
 		if( isset($install_to) )
 		{
 
-			include($phpbb_root_path. "templates/" . $install_to . "/theme_info.cfg");
+			include($phpbb_root_path. "templates/" . basename($install_to) . "/theme_info.cfg");
 
 			$template_name = $$install_to;
 			$found = FALSE; 
@@ -582,6 +582,7 @@ switch( $mode )
 				"L_SIMPLE_NAME" => $lang['Simple_name'],
 				"L_VALUE" => $lang['Value'],
 				"L_STYLESHEET" => $lang['Stylesheet'],
+				"L_STYLESHEET_EXPLAIN" => $lang['Stylesheet_explain'],
 				"L_BACKGROUND_IMAGE" => $lang['Background_image'],
 				"L_BACKGROUND_COLOR" => $lang['Background_color'],
 				"L_BODY_TEXT_COLOR" => $lang['Text_color'],
@@ -739,7 +740,7 @@ switch( $mode )
 			
 			@umask(0111);
 
-			$fp = @fopen($phpbb_root_path . 'templates/' . $template_name . '/theme_info.cfg', 'w');
+			$fp = @fopen($phpbb_root_path . 'templates/' . basename($template_name) . '/theme_info.cfg', 'w');
 
 			if( !$fp )
 			{
