@@ -6,7 +6,7 @@
  *   copyright            : (C) 2001 The phpBB Group
  *   email                : support@phpbb.com
  *
- *   $Id: index.php,v 1.40.2.7 2005/02/21 18:37:02 acydburn Exp $
+ *   $Id: index.php,v 1.40.2.8 2005/09/18 16:17:20 acydburn Exp $
  *
  *
  ***************************************************************************/
@@ -567,7 +567,7 @@ elseif( isset($HTTP_GET_VARS['pane']) && $HTTP_GET_VARS['pane'] == 'right' )
 	$errno = 0;
 	$errstr = $version_info = '';
 
-	if ($fsock = @fsockopen('www.phpbb.com', 80, $errno, $errstr))
+	if ($fsock = @fsockopen('www.phpbb.com', 80, $errno, $errstr, 10))
 	{
 		@fputs($fsock, "GET /updatecheck/20x.txt HTTP/1.1\r\n");
 		@fputs($fsock, "HOST: www.phpbb.com\r\n");
@@ -602,7 +602,7 @@ elseif( isset($HTTP_GET_VARS['pane']) && $HTTP_GET_VARS['pane'] == 'right' )
 		else
 		{
 			$version_info = '<p style="color:red">' . $lang['Version_not_up_to_date'];
-			$version_info .= '<br />' . sprintf($lang['Latest_version_info'], $latest_version) . sprintf($lang['Current_version_info'], '2' . $board_config['version']) . '</p>';
+			$version_info .= '<br />' . sprintf($lang['Latest_version_info'], $latest_version) . ' ' . sprintf($lang['Current_version_info'], '2' . $board_config['version']) . '</p>';
 		}
 	}
 	else
