@@ -2,7 +2,7 @@
 
   mssql_schema.sql for phpBB2 (c) 2001, phpBB Group
 
- $Id: mssql_schema.sql,v 1.1.2.7 2003/06/30 17:18:37 acydburn Exp $
+ $Id: mssql_schema.sql,v 1.1.2.9 2005/10/30 15:17:14 acydburn Exp $
 
 */
 
@@ -190,7 +190,16 @@ CREATE TABLE [phpbb_sessions] (
 	[session_time] [int] NULL ,
 	[session_ip] [char] (8) NOT NULL ,
 	[session_page] [int] NULL ,
-	[session_logged_in] [smallint] NULL
+	[session_logged_in] [smallint] NULL,
+	[session_admin] [smallint] NULL
+) ON [PRIMARY]
+GO
+
+CREATE TABLE [phpbb_sessions_keys] (
+  [key_id] [char] (32) NOT NULL ,
+  [user_id] [int] NOT NULL ,
+  [last_ip] [char] (8) NOT NULL ,
+  [last_login] [int] NOT NULL
 ) ON [PRIMARY]
 GO
 
@@ -615,6 +624,7 @@ ALTER TABLE [phpbb_users] WITH NOCHECK ADD
 	CONSTRAINT [DF_phpbb_users_user_allow_viewonline] DEFAULT (1) FOR [user_allow_viewonline],
 	CONSTRAINT [DF_phpbb_users_user_notify_pm] DEFAULT (0) FOR [user_notify_pm],
 	CONSTRAINT [DF_phpbb_users_user_popup_pm] DEFAULT (1) FOR [user_popup_pm],
+	CONSTRAINT [DF_phpbb_users_user_dateformat] DEFAULT('d M Y H:i') FOR [user_dateformat],
 	CONSTRAINT [DF_phpbb_users_user_avatar_type] DEFAULT (0) FOR [user_avatar_type]
 GO
 
@@ -666,6 +676,12 @@ GO
  CREATE  INDEX [IX_phpbb_sessions] ON [phpbb_sessions]([session_id], [session_user_id], [session_ip], [session_logged_in]) ON [PRIMARY]
 GO
 
+ CREATE  INDEX [IX_phpbb_sessions_keys] ON [phpbb_sessions_keys]([key_id], [user_id]) ON [PRIMARY]
+GO
+
+ CREATE  INDEX [IX_phpbb_sessions_keys] ON [phpbb_sessions_keys]([last_login]) ON [PRIMARY]
+GO
+
  CREATE  INDEX [IX_phpbb_topics] ON [phpbb_topics]([forum_id], [topic_type], [topic_first_post_id], [topic_last_post_id]) ON [PRIMARY]
 GO
 
