@@ -1,7 +1,7 @@
 #
 # phpBB2 - MySQL schema
 #
-# $Id: mysql_schema.sql,v 1.35.2.7 2003/06/10 12:42:31 psotfx Exp $
+# $Id: mysql_schema.sql,v 1.35.2.9 2005/10/30 15:17:14 acydburn Exp $
 #
 
 #
@@ -305,11 +305,25 @@ CREATE TABLE phpbb_sessions (
    session_ip char(8) DEFAULT '0' NOT NULL,
    session_page int(11) DEFAULT '0' NOT NULL,
    session_logged_in tinyint(1) DEFAULT '0' NOT NULL,
+   session_admin tinyint(2) DEFAULT '0' NOT NULL,
    PRIMARY KEY (session_id),
    KEY session_user_id (session_user_id),
    KEY session_id_ip_user_id (session_id, session_ip, session_user_id)
 );
 
+# --------------------------------------------------------
+#
+# Table structure for table `phpbb_sessions_keys`
+#
+CREATE TABLE phpbb_sessions_keys (
+  key_id varchar(32) DEFAULT '0' NOT NULL,
+  user_id mediumint(8) DEFAULT '0' NOT NULL,
+  last_ip varchar(8) DEFAULT '0' NOT NULL,
+  last_login int(11) DEFAULT '0' NOT NULL,
+  PRIMARY KEY (key_id, user_id),
+  KEY last_login (last_login)
+);
+
 
 # --------------------------------------------------------
 #
