@@ -2,7 +2,7 @@
  phpBB2 PostgreSQL DB schema - phpBB group 2001
 
 
- $Id: postgres_schema.sql,v 1.1.2.4 2003/06/10 12:42:31 psotfx Exp $
+ $Id: postgres_schema.sql,v 1.1.2.6 2005/10/30 15:17:14 acydburn Exp $
 */
 
 CREATE SEQUENCE phpbb_banlist_id_seq start 1 increment 1 maxvalue 2147483647 minvalue 1 cache 1;
@@ -289,11 +289,23 @@ CREATE TABLE phpbb_sessions (
    session_ip char(8) DEFAULT '0' NOT NULL,
    session_page int4 DEFAULT '0' NOT NULL,
    session_logged_in int2 DEFAULT '0' NOT NULL,
+   session_admin int2 DEFAULT '0' NOT NULL,
    CONSTRAINT phpbb_session_pkey PRIMARY KEY (session_id)
 );
 CREATE INDEX session_user_id_phpbb_sessions_index ON phpbb_sessions (session_user_id);
 CREATE INDEX session_id_ip_user_id_phpbb_sessions_index ON phpbb_sessions (session_id, session_ip, session_user_id);
 
+/* --------------------------------------------------------
+  Table structure for table phpbb_sessions_keys
+-------------------------------------------------------- */
+CREATE TABLE phpbb_sessions_keys (
+  key_id char(32) DEFAULT '0' NOT NULL,
+  user_id int4 DEFAULT '0' NOT NULL,
+  last_ip char(8) DEFAULT '0' NOT NULL,
+  last_login int4 DEFAULT '0' NOT NULL,
+  CONSTRAINT phpbb_sessions_keys_pkey PRIMARY KEY (key_id, user_id)
+);
+CREATE INDEX last_login_phpbb_sessions_keys_index ON phpbb_sessions_keys (last_login);
 
 /* --------------------------------------------------------
   Table structure for table phpbb_smilies
@@ -488,10 +500,10 @@ CREATE TABLE phpbb_users (
    user_rank int4 DEFAULT '0',
    user_avatar varchar(100),
    user_avatar_type int2 DEFAULT '0' NOT NULL,
-   user_level int4 DEFAULT '1',
+   user_level int4 DEFAULT '0',
    user_lang varchar(255),
    user_timezone decimal(5) DEFAULT '0' NOT NULL,
-   user_dateformat varchar(14) DEFAULT 'd M Y H:m' NOT NULL,
+   user_dateformat varchar(14) DEFAULT 'd M Y H:i' NOT NULL,
    user_notify_pm int2 DEFAULT '0' NOT NULL,
    user_popup_pm int2 DEFAULT '0' NOT NULL,
    user_notify int2,
