@@ -6,7 +6,7 @@
  *   copyright            : (C) 2001 The phpBB Group
  *   email                : support@phpbb.com
  *
- *   $Id: update_to_latest.php,v 1.1.2.1 2005/02/21 18:38:40 acydburn Exp $
+ *   $Id: update_to_latest.php,v 1.1.2.8 2005/10/30 15:17:14 acydburn Exp $
  *
  ***************************************************************************/
 
@@ -59,7 +59,7 @@ include($phpbb_root_path . 'includes/db.'.$phpEx);
 //
 //
 //
-$updates_to_version = '.0.13';
+$updates_to_version = '.0.18';
 //
 //
 //
@@ -420,6 +420,8 @@ switch ($row['config_value'])
 			
 		}
 
+	case '.0.2':
+
 	case '.0.3':
 
 		switch (SQL_LAYER)
@@ -463,7 +465,7 @@ switch ($row['config_value'])
 					AS SELECT group_id, group_name, group_type, group_description, group_moderator, group_single_user 
 						FROM " . GROUPS_TABLE;
 				$sql[] = "DROP TABLE " . GROUPS_TABLE;
-				$sql[] = "CREATE TABLE phpbb_groups (group_id int DEFAULT nextval('" . GROUPS_TABLE . "_id_seq'::text) NOT NULL, group_name varchar(40) NOT NULL, group_type int2 DEFAULT '1' NOT NULL, group_description varchar(255) NOT NULL, group_moderator int4 DEFAULT '0' NOT NULL, group_single_user int2 DEFAULT '0' NOT NULL, CONSTRAINT phpbb_groups_pkey PRIMARY KEY (group_id))";
+				$sql[] = "CREATE TABLE {$table_prefix}groups (group_id int DEFAULT nextval('" . GROUPS_TABLE . "_id_seq'::text) NOT NULL, group_name varchar(40) NOT NULL, group_type int2 DEFAULT '1' NOT NULL, group_description varchar(255) NOT NULL, group_moderator int4 DEFAULT '0' NOT NULL, group_single_user int2 DEFAULT '0' NOT NULL, CONSTRAINT {$table_prefix}groups_pkey PRIMARY KEY (group_id))";
 				$sql[] = "INSERT INTO " . GROUPS_TABLE . " (group_id, group_name, group_type, group_description, group_moderator, group_single_user) 
 					SELECT group_id, group_name, group_type, group_description, group_moderator, group_single_user 
 						FROM tmp_" . GROUPS_TABLE;
@@ -509,7 +511,76 @@ switch ($row['config_value'])
 				break;
 
 			case 'postgresql':
-				$sql[] = 'CREATE TABLE ' . $table_prefix . 'confirm (confirm_id char(32) DEFAULT \'\' NOT NULL,  session_id char(32) DEFAULT \'\' NOT NULL, code char(6) DEFAULT \'\' NOT NULL, CONSTRAINT phpbb_confirm_pkey PRIMARY KEY (session_id, confirm_id))';
+				$sql[] = 'CREATE TABLE ' . $table_prefix . 'confirm (confirm_id char(32) DEFAULT \'\' NOT NULL,  session_id char(32) DEFAULT \'\' NOT NULL, code char(6) DEFAULT \'\' NOT NULL, CONSTRAINT {$table_prefix}confirm_pkey PRIMARY KEY (session_id, confirm_id))';
+				break;
+		}
+
+	case '.0.5':
+	case '.0.6':
+	case '.0.7':
+	case '.0.8':
+	case '.0.9':
+	case '.0.10':
+	case '.0.11':
+	case '.0.12':
+	case '.0.13':
+	case '.0.14':
+
+		switch (SQL_LAYER)
+		{
+			case 'mysql':
+			case 'mysql4':
+				$sql[] = "ALTER TABLE " . SESSIONS_TABLE . "
+					ADD COLUMN session_admin tinyint(2) DEFAULT '0' NOT NULL";
+				break;
+
+			case 'postgresql':
+				$sql[] = "ALTER TABLE " . SESSIONS_TABLE . "
+					ADD COLUMN session_admin int2";
+				$sql[] = "ALTER TABLE " . SESSIONS_TABLE . "
+					ALTER COLUMN session_admin SET DEFAULT '0'";
+				break;
+
+			case 'mssql-odbc':
+			case 'mssql':
+				$sql[] = "ALTER TABLE " . SESSIONS_TABLE . " ADD
+					session_admin smallint NOT NULL,
+					CONSTRAINT [DF_" . $table_prefix . "sessions_session_admin] DEFAULT (0) FOR [session_admin]";
+				break;
+
+			case 'msaccess':
+				$sql[] = "ALTER TABLE " . SESSIONS_TABLE . " ADD
+					session_admin smallint NOT NULL";
+				break;
+		}
+
+	case '.0.15':
+	case '.0.16':
+	case '.0.17':
+		// Add tables for session keys
+		switch (SQL_LAYER)
+		{
+			case 'mysql':
+			case 'mysql4':
+				$sql[] = 'CREATE TABLE ' . $table_prefix . 'sessions_keys (key_id varchar(32) DEFAULT \'0\' NOT NULL, user_id mediumint(8) DEFAULT \'0\' NOT NULL, last_ip varchar(8) DEFAULT \'0\' NOT NULL, last_login int(11) DEFAULT \'0\' NOT NULL, PRIMARY KEY (key_id, user_id), KEY last_login (last_login))';
+				break;
+
+			case 'mssql':
+			case 'mssql-odbc':
+				$sql[] = 'CREATE TABLE [' . $table_prefix . 'sessions_keys] ([key_id] [char] (32) NOT NULL , [user_id] [int] NOT NULL , [last_ip] [char] (8) NOT NULL , [last_login] [int] NOT NULL) ON [PRIMARY]';
+
+				$sql[] = 'CREATE INDEX [IX_' . $table_prefix . 'sessions_keys] ON [' . $table_prefix . 'sessions_keys]([key_id], [user_id]) ON [PRIMARY]';
+				$sql[] = 'CREATE  INDEX [IX_' . $table_prefix . 'sessions_keys] ON [' . $table_prefix . 'sessions_keys]([last_login]) ON [PRIMARY]';
+				break;
+
+			case 'msaccess':
+				$sql[] = 'CREATE TABLE ' . $table_prefix . 'sessions_keys (key_id char(32) NOT NULL, user_id int NOT NULL, last_ip char(8) NOT NULL, last_login int NOT NULL)';
+				$sql[] = 'ALTER TABLE ' . $table_prefix . 'sessions_keys ADD PRIMARY KEY (key_id, user_id)';
+				break;
+
+			case 'postgresql':
+				$sql[] = 'CREATE TABLE ' . $table_prefix . 'sessions_keys (key_id char(32) DEFAULT \'0\' NOT NULL, user_id int4 DEFAULT \'0\' NOT NULL, last_ip char(8) DEFAULT \'0\' NOT NULL, last_login int4 DEFAULT \'0\' NOT NULL, CONSTRAINT ' . $table_prefix . 'sessions_keys_pkey PRIMARY KEY (key_id, user_id))';
+				$sql[] = 'CREATE INDEX last_login_' . $table_prefix . 'sessions_keys_index ON ' . $table_prefix . 'sessions_keys (last_login)';
 				break;
 		}
 
@@ -900,6 +971,37 @@ switch ($row['config_value'])
 		}
 		$db->sql_freeresult($result);
 		
+	case '.0.6':
+	case '.0.7':
+	case '.0.8':
+	case '.0.9':
+	case '.0.10':
+	case '.0.11':
+	case '.0.12':
+	case '.0.13':
+	case '.0.14':
+
+		$sql = 'UPDATE ' . USERS_TABLE . ' SET user_allowhtml = 1 WHERE user_id = ' . ANONYMOUS;
+		_sql($sql, $errored, $error_ary);
+
+	case '.0.15':
+	case '.0.16':
+	case '.0.17':
+
+		$sql = 'UPDATE ' . USERS_TABLE . ' SET user_active = 0 WHERE user_id = ' . ANONYMOUS;
+		_sql($sql, $errored, $error_ary);
+
+		$sql = 'INSERT INTO ' . CONFIG_TABLE . " (config_name, config_value)
+			VALUES ('allow_autologin', '1')";
+		_sql($sql, $errored, $error_ary);
+
+		$sql = 'INSERT INTO ' . CONFIG_TABLE . " (config_name, config_value)
+			VALUES ('max_autologin_time', '0')";
+		_sql($sql, $errored, $error_ary);
+		
+		// We reset those having autologin enabled and forcing the re-assignment of a session id
+		$sql = 'DELETE FROM ' . SESSIONS_TABLE;
+		_sql($sql, $errored, $error_ary);
 		break;
 
 	default:
